{% extends "feedme/base.html" %}

{% block content %}
<table>
  <form action="" method="post" enctype="multipart/form-data">
    {{ form }}
    <tr>
      <td colspan="2">
        {% csrf_token %}
        <input type="submit" value="Import">
      </td>
    </tr>
  </form>
</table>
For getting all your subscription, open <a href="http://www.google.com/reader/" target="_blank">GoogleReader</a>
Settings, and click to Import & Export tab.
Download your data through Takeout and choose zip file at this form.
{% endblock %}